﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Xml;
using ThomsonReuters.Eikon.Integration;

namespace EikonDesktopApp2
{
    /// <summary>
    /// Interaction logic for MainControl.xaml
    /// </summary>
    [EikonAppStart]
    public partial class MainControl : UserControl
    {
        public IAppHost EikonHost { get; private set; }

        public MainControl()
        {
            SetProductStyle();
            InitializeComponent();
            lblHelloWorld.Content = "Hello world";
            //LogExample();  //uncomment to test logging
        }

        private void SetProductStyle()
        {
            try
            {
                Application app = Application.Current;
                var appResources = new ResourceDictionary
                {
                    Source =
                        new Uri("pack://application:,,,/ThomsonReuters.Desktop.SDK.UI;component/Resources/NovaSkin.xaml")
                };
                app.Resources.MergedDictionaries.Add(appResources);
            }
            catch (Exception ex)
            {
                //Log 
            }
        }

        /// <summary>
        /// Use this constructor if you want to integrate with Eikon
        /// </summary>
        /// <param name="eikonHost"></param>
        public MainControl(IAppHost eikonHost)
            : this()
        {
            EikonHost = eikonHost;
            eikonHost.Closing += Host_Closing;
            //eikonHost.OnSave(OnSave); //uncomment to test load / save
        }

        #region Load/Save XML Preferences

        /// <summary>
        /// Use this constructor if you want to integrate with Eikon and also retrieve saved data
        /// TO TEST: 
        /// 1. Uncomment constructor 
        /// 2. Uncomment OnSave Call and 
        /// 3. Start the app in debugger
        /// 4. Right click "Workspace" in Eikon and select "Save"
        /// 5. "OnSave" will get control
        /// 6. Click on "Run Eikon Application" and the constructor below will get called with saved preferences
        /// </summary>
        /// <param name="eikonHost"></param>
        /// <param name="appSavedPreferences"></param>
        public MainControl(IAppHost eikonHost, XmlReader appSavedPreferences)
            : this(eikonHost)
        {
            if (appSavedPreferences == null)
            {
                return;
            }
            //process xml data saved in last IAppHost.OnSave() event
            while (appSavedPreferences.Read())
            {

            }
        }

        //private void OnSave(XmlWriter writer)
        //{
        //    writer.WriteStartDocument();
        //    writer.WriteStartElement("Preferences");

        //    writer.WriteStartElement("State");
        //    writer.WriteAttributeString("LastSecurity", "MSFT.O");
        //    writer.WriteEndElement();

        //    writer.WriteEndElement();
        //    writer.WriteEndDocument();
        //}

        #endregion

        #region To get loaded context / active company
        /// <summary>
        /// Use this constructor if you want to integrate with Eikon and get the loaded instrument
        /// </summary>
        /// <param name="eikonHost"></param>
        /// <param name="eikonContext"></param>
        //public MainControl(IAppHost eikonHost, IContext eikonContext)
        //    : this(eikonHost)
        //{
        //    //process loaded context retrieved in the eikonContext
        //}

        #endregion


        /// <summary>
        /// Eikon will call this event handler when the app is being closed.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

        private void Host_Closing(object sender, ClosingEventArgs e)
        {
        }

        #region LogExample
        //private void LogExample()
        //{
        //    var commonLoggerSource = LogManager.GetCurrentClassLogger();
        //    commonLoggerSource.Error("Log Error to common source");

        //    var appLoggerSource = LogManager.GetLogger("AppSource");
        //    appLoggerSource.Error("Log Error to App Source");
        //}

        #endregion
    }
}
